==> 1.14.6.zip: acidisland/README.md <==
AcidIsland™
===========
[![Build Status](https://ci.codemc.org/buildStatus/icon?job=BentoBoxWorld/AcidIsland)](https://ci.codemc.org/job/BentoBoxWorld/job/AcidIsland/)
[![Lines Of Code](https://sonarcloud.io/api/project_badges/measure?project=world.bentobox%3Aacidisland&metric=ncloc)](https://sonarcloud.io/component_measures?id=world.bentobox%3Aacidisland&metric=ncloc)
[![Maintainability Rating](https://sonarcloud.io/api/project_badges/measure?project=world.bentobox%3Aacidisland&metric=sqale_rating)](https://sonarcloud.io/component_measures?id=world.bentobox%3Aacidisland&metric=Maintainability)
[![Reliability Rating](https://sonarcloud.io/api/project_badges/measure?project=world.bentobox%3Aacidisland&metric=reliability_rating)](https://sonarcloud.io/component_measures?id=world.bentobox%3Aacidisland&metric=Reliability)
[![Security Rating](https://sonarcloud.io/api/project_badges/measure?project=world.bentobox%3Aacidisland&metric=security_rating)](https://sonarcloud.io/component_measures?id=world.bentobox%3Aacidisland&metric=Security)
[![Bugs](https://sonarcloud.io/api/project_badges/measure?project=world.bentobox%3Aacidisland&metric=bugs)](https://sonarcloud.io/project/issues?id=world.bentobox%3Aacidisland&resolved=false&types=BUG)

# Introduction
AcidIsland™ add-on for BentoBox, so to run an AcidIsland™ game, you must have BentoBox installed. It is not a Bukkit plugin and trying to use it as one will not work.


## The Story
You're on an island, in a sea of acid! If you like Skyblock, try the AcidIsland™ game mode for a new challenge!

This is a variation of SkyBlock. Instead of falling, you must contend with acid water when expanding your island and players can boat to each other's islands.

## Installation

0. Install BentoBox and run it on the server at least once to create its data folders.
1. Place this jar in the addons folder of the BentoBox plugin.
2. Restart the server.
3. The addon will create worlds and a data folder and inside the folder will be a config.yml.
4. Stop the server.
5. Edit the config.yml how you want.
6. Delete any worlds that were created by default if you made changes that would affect them.
7. Restart the server.

### Other Add-ons

AcidIsland™ add-on uses the BentoBox API. Here are some other ones that you may be interested in:

* Level - provides island level calculation and a top ten
* Welcome Warps - provides the warp sign feature
* Challenges - challenges
* Biomes - enables biomes

You can find the projects on GitHub.

Bugs and Feature requests
=========================
File bug and feature requests here: https://github.com/BentoBoxWorld/AcidIsland/issues

==> 1.16.0.zip: acidisland/README.md <==
AcidIsland™
===========
[![Build Status](https://ci.codemc.org/buildStatus/icon?job=BentoBoxWorld/AcidIsland)](https://ci.codemc.org/job/BentoBoxWorld/job/AcidIsland/)
[![Lines Of Code](https://sonarcloud.io/api/project_badges/measure?project=world.bentobox%3Aacidisland&metric=ncloc)](https://sonarcloud.io/component_measures?id=world.bentobox%3Aacidisland&metric=ncloc)
[![Maintainability Rating](https://sonarcloud.io/api/project_badges/measure?project=world.bentobox%3Aacidisland&metric=sqale_rating)](https://sonarcloud.io/component_measures?id=world.bentobox%3Aacidisland&metric=Maintainability)
[![Reliability Rating](https://sonarcloud.io/api/project_badges/measure?project=world.bentobox%3Aacidisland&metric=reliability_rating)](https://sonarcloud.io/component_measures?id=world.bentobox%3Aacidisland&metric=Reliability)
[![Security Rating](https://sonarcloud.io/api/project_badges/measure?project=world.bentobox%3Aacidisland&metric=security_rating)](https://sonarcloud.io/component_measures?id=world.bentobox%3Aacidisland&metric=Security)
[![Bugs](https://sonarcloud.io/api/project_badges/measure?project=world.bentobox%3Aacidisland&metric=bugs)](https://sonarcloud.io/project/issues?id=world.bentobox%3Aacidisland&resolved=false&types=BUG)

# Introduction
AcidIsland™ add-on for BentoBox, so to run an AcidIsland™ game, you must have BentoBox installed. Docs can be found at [https://docs.bentobox.world](https://docs.bentobox.world).


## The Story
You're on an island, in a sea of acid! If you like Skyblock, try the AcidIsland™ game mode for a new challenge!

Instead of falling you must contend with acid water when expanding your island, and players can boat to each other's islands.

## Download

You can download from GitHub, or ready made plugin packs from [https://download.bentobox.world](https://download.bentobox.world).

## Installation

0. Install BentoBox and run it on the server at least once to create its data folders.
1. Place this jar in the addons folder of the BentoBox plugin.
2. Restart the server.
3. The addon will create worlds and a data folder and inside the folder will be a config.yml.
4. Stop the server.
5. Edit the config.yml how you want.
6. Delete any worlds that were created by default if you made changes that would affect them.
7. Restart the server.

### Other Add-ons

AcidIsland™ add-on uses the BentoBox API. Here are some other ones that you may be interested in:

* Level - provides island level calculation and a top ten
* Welcome Warps - provides the warp sign feature
* Challenges - challenges
* Biomes - enables biomes

You can find the projects on GitHub or download load from [https://download.bentobox.world](https://download.bentobox.world).

Bugs and Feature requests
=========================
File bug and feature requests here: [https://github.com/BentoBoxWorld/AcidIsland/issues](https://github.com/BentoBoxWorld/AcidIsland/issues)
